@@ -17,7 +17,7 @@ use App::VTide::Hooks;
 use Path::Tiny;
 use YAML::Syck qw/ LoadFile DumpFile /;
 
-our $VERSION = version->new('0.0.3');
+our $VERSION = version->new('0.0.4');
 
 has config => (
     is      => 'rw',
@@ -53,6 +53,10 @@ sub run {
                     print join ' ', sort keys %{ $self->sub_commands };
                     return;
                 }
+                elsif ( ! $self->sub_commands->{$sub_command} ) {
+                    unshift @{$option->files}, $sub_command;
+                    $sub_command = 'start';
+                }
                 eval {
                     $self->load_subcommand( $sub_command, $option )->auto_complete();
                     1;
@@ -76,16 +80,21 @@ sub run {
 
     my $subcommand = eval { $self->load_subcommand( $opt->cmd, $opt ) };
     if ( ! $subcommand ) {
-        my $error = $@;
-        warn $@ if $opt->opt->verbose;
-        warn "Unknown command '$cmd'!\n",
-            "Valid commands - ", ( join ', ', sort keys %{ $self->sub_commands } ),
-            "\n";
-        require Pod::Usage;
-        Pod::Usage::pod2usage(
-            -verbose => 1,
-            -input   => __FILE__,
-        );
+        $subcommand = $self->load_subcommand( 'start', $opt );
+        my (undef, $dir) = $subcommand->session_dir($opt->cmd);
+        if ( !$dir ) {
+            my $error = $@;
+            warn $@ if $opt->opt->verbose;
+            warn "Unknown command '$cmd'!\n",
+                "Valid commands - ", ( join ', ', sort keys %{ $self->sub_commands } ),
+                "\n";
+            require Pod::Usage;
+            Pod::Usage::pod2usage(
+                -verbose => 1,
+                -input   => __FILE__,
+            );
+        }
+        unshift @{ $opt->files }, $opt->cmd;
     }
 
     return $subcommand->run;
@@ -142,14 +151,15 @@ __END__
 
 =head1 NAME
 
-App::VTide - A vim/tmux baised IDE for the terminal
+App::VTide - A vim/tmux based IDE for the terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide version 0.0.3
+This documentation refers to App::VTide version 0.0.4
 
 =head1 SYNOPSIS
 
+    vtide [start] [project]
     vtide (init|start|refresh|run|edit|save|conf|help) [options]
 
   COMMANDS:
@@ -165,10 +175,14 @@ This documentation refers to App::VTide version 0.0.3
   Examples:
     # start a new project, name taken from the directory name
     vtide init
+    # start a new project specifying the project name
+    vtide init --name my-project
     # start the project in the current directory
     vtide start
     # start the "my-project" project previously initialised
     vtide start my-project
+    # or lazy shortcut
+    vtide my-project
 
 =head1 DESCRIPTION
 
@@ -176,7 +190,7 @@ VTide provides a way to manage L<tmux> sessions. It allows for an easy way
 to configure a session window and run programs or open files for editing
 in them. The aim is to allow for easy project setup and management for
 projects managed on the command line. L<App::VTide> also includes helpers
-for loading files into editors (such as vim) in seperate tmux terminals.
+for loading files into editors (such as vim) in separate tmux terminals.
 This can help to open pre-defined groups of files.
 
 =head2 Philosophy
